'use strict';
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');
var _ = require('underscore.string');

module.exports = yeoman.generators.Base.extend({
    prompting: function () {
        var done = this.async();

        // Have Yeoman greet the user.
        this.log(yosay(
            'Welcome to the sensational ' + chalk.red('AngularLaravel') + ' generator!'
        ));
        var prompts = [];

        this.prompt(prompts, function (props) {
            this.props = props;
            done();
        }.bind(this));
    },

    writing: {
        app: function () {
            this.appName = _.slugify(process.cwd().split('/').pop());
            this.dirPath = this.destinationRoot();
            this.publicPath = this.dirPath + '/public';
            this.destinationRoot(this.publicPath);
            this.fs.copyTpl(
                this.templatePath('_package.json'),
                this.destinationPath('package.json'),
                { name: this.appName  }
            );
            this.fs.copyTpl(
                this.templatePath('_bower.json'),
                this.destinationPath('bower.json'),
                { name: this.appName  }
            );
            this.fs.copy(
                this.templatePath('_.bowerrc'),
                this.destinationPath('.bowerrc')
            );
        },
        views: function () {
            this.resourcePath = this.dirPath + '/public/views';
            this.destinationRoot(this.resourcePath);
            this.fs.copyTpl(
                this.templatePath('_home.html'),
                this.destinationPath('/commons/home.html'),
                { name: this.appName  }
            );
            this.fs.copy(
                this.templatePath('_404.html'),
                this.destinationPath('/commons/404.html')
            );
            this.laravelViewPath = this.dirPath + '/resources/views';
            this.destinationRoot(this.laravelViewPath);
            this.fs.copyTpl(
                this.templatePath('_index.blade.php'),
                this.destinationPath('welcome.blade.php'),
                { name: this.appName  }
            );
        },
        scripts: function () {
            this.srcPath = this.dirPath + '/public/js';
            this.destinationRoot(this.srcPath);
            this.fs.copyTpl(
                this.templatePath('_app.js'),
                this.destinationPath('app.js'),
                { name: this.appName  }
            );
            this.fs.copyTpl(
                this.templatePath('_routes.js'),
                this.destinationPath('routes.js'),
                { name: this.appName  }
            );
            this.fs.copyTpl(
                this.templatePath('_controllers.js'),
                this.destinationPath('controllers.js'),
                { name: this.appName  }
            );
            this.fs.copyTpl(
                this.templatePath('_HomeCtrl.js'),
                this.destinationPath('/controllers/HomeCtrl.js'),
                { name: this.appName  }
            );
        },
        css: function () {
            this.cssPath = this.dirPath+'/public/css';
            this.destinationRoot(this.cssPath);
            this.fs.copy(
                this.templatePath('_app.css'),
                this.destinationPath('app.css')
            );
        },
        projectfiles: function () {
            this.destinationRoot(this.publicPath);
            this.fs.copy(
                this.templatePath('editorconfig'),
                this.destinationPath('.editorconfig')
            );
            this.fs.copy(
                this.templatePath('jshintrc'),
                this.destinationPath('.jshintrc')
            );
        }
    },

    install: function () {
        this.installDependencies();
    }
});
